export declare type supportTypes = 'uweb' | 'baidu';
export interface uwebConfig {
    src?: string;
    siteId: string;
    autoPageview?: boolean;
}
export interface baiduConfig {
    src?: string;
    siteId: string;
}
export declare type supportConfig = uwebConfig | baiduConfig;
export interface loggerConfig {
    debug: false;
    config: supportConfig;
}
export interface uwebOptions {
    category: string;
    action: string;
    label?: string;
    value?: string;
    nodeid?: string;
    type?: 'trackPageview' | 'trackEvent' | 'setCustomVar' | 'setAccount' | 'setAutoPageview' | 'deleteCustomVar';
}
export interface baiduOptions {
    category: string;
    action: string;
    opt_label?: string;
    opt_value?: string;
    type?: 'trackPageview' | 'trackEvent';
}
export interface baseLogger {
    send(options: supportConfig | string, data: string): void;
    [x: string]: any;
}
export interface logger {
    (loggerConfig: loggerConfig): Promise<baseLogger>;
}
export interface reporterConfig {
    (logOptions: config): Promise<reporterConfig>;
    Vue: object;
    options: config;
    send(value: any, data?: any, event?: Event): void;
    beforeInit?(config: supportConfig): void;
    reporter?: baseLogger;
}
export interface tonpOptions {
    et: number;
    dt: number;
}
export interface config {
    autoClick?: boolean;
    autoSend?: boolean;
    autoError?: boolean;
    autoErrorSend?: boolean;
    debug?: boolean;
    type: supportTypes;
    config: supportConfig;
    beforeInit?(options: supportConfig): void;
    onSend?(sendEvent: supportConfig | string, sendData?: any, reporter?: baseLogger, event?: Event): void;
    onPageview?(ctx: reporterConfig): void;
    onTonp?(ctx: reporterConfig, time: tonpOptions): void;
    onError?(error: any, ctx: reporterConfig): void;
}
